@@ -7,8 +7,9 @@ def send(name, text, newline=True):
     '''
     if newline:
         text = text + '\n'
-    run('screen -S %s -p0 -X stuff \'%s\n\'' % (name, text))
-    
+    run('screen -S %s -p0 -X stuff \'%s\'' % (name, text))
+
+ 
 def exists(name):
     '''exists [screen name]
     Returns True/False wehther there is a screen of that name active.
@@ -18,11 +19,15 @@ def exists(name):
         return True
     return False
 
-def new(name, command):
+
+def new(name, command, logging=False):
     '''new [screen name], [shell command]
     Starts up a new screen console using the name and command specified.
     '''
-    run('screen -dmLS %s bash -c \'%s\'' % (name, command))
+    l = ''
+    if logging: l = 'L'
+    run('screen -d%smS %s bash -c \'%s\'' % (l, name, command))
+
 
 def console(name):
     '''console [screen name]
@@ -30,5 +35,6 @@ def console(name):
     '''
     os.system('screen -DRS %s' % name)
 
+
 def kill(name):
     pass
\ No newline at end of file
